@@ -316,6 +316,16 @@ impl BuildOptions {
                         }
                         interpreters =
                             find_interpreter_in_sysconfig(interpreter, target, requires_python)?;
+                        if interpreters.is_empty() {
+                            bail!(
+                                "Couldn't find any python interpreters from '{}'. Please check that both major and minor python version have been specified in -i/--interpreter.",
+                                interpreter
+                                    .iter()
+                                    .map(|p| p.display().to_string())
+                                    .collect::<Vec<_>>()
+                                    .join(", ")
+                            );
+                        }
                     }
                 } else if binding_name.starts_with("pyo3") {
                     // Only pyo3/pyo3-ffi bindings supports bundled sysconfig interpreters
@@ -373,7 +383,7 @@ impl BuildOptions {
                             InterpreterConfig::from_pyo3_config(config_file.as_ref(), target)
                                 .context("Invalid PYO3_CONFIG_FILE")?;
                         Ok(vec![PythonInterpreter::from_config(interpreter_config)])
-                    } else if let Some(interp) = interpreters.get(0) {
+                    } else if let Some(interp) = interpreters.first() {
                         eprintln!("🐍 Using {interp} to generate to link bindings (With abi3, an interpreter is only required on windows)");
                         Ok(interpreters)
                     } else if generate_import_lib {
@@ -484,7 +494,7 @@ impl BuildOptions {
             pyproject_toml_path,
             pyproject_toml,
             module_name,
-            metadata21,
+            metadata23,
             mut cargo_options,
             cargo_metadata,
             mut pyproject_toml_maturin_options,
@@ -554,7 +564,7 @@ impl BuildOptions {
                 &bridge,
                 &[],
                 &target,
-                metadata21.requires_python.as_ref(),
+                metadata23.requires_python.as_ref(),
                 generate_import_lib,
             )?
         } else {
@@ -668,7 +678,7 @@ impl BuildOptions {
             project_layout,
             pyproject_toml_path,
             pyproject_toml,
-            metadata21,
+            metadata23,
             crate_name,
             module_name,
             manifest_path: cargo_toml_path,
