@@ -69,9 +69,12 @@ pub enum Arch {
     X86_64,
     S390X,
     Wasm32,
+    Riscv32,
     Riscv64,
     Mips64el,
+    Mips64,
     Mipsel,
+    Mips,
     Sparc64,
     LoongArch64,
 }
@@ -89,9 +92,12 @@ impl fmt::Display for Arch {
             Arch::X86_64 => write!(f, "x86_64"),
             Arch::S390X => write!(f, "s390x"),
             Arch::Wasm32 => write!(f, "wasm32"),
+            Arch::Riscv32 => write!(f, "riscv32"),
             Arch::Riscv64 => write!(f, "riscv64"),
             Arch::Mips64el => write!(f, "mips64el"),
+            Arch::Mips64 => write!(f, "mips64"),
             Arch::Mipsel => write!(f, "mipsel"),
+            Arch::Mips => write!(f, "mips"),
             Arch::Sparc64 => write!(f, "sparc64"),
             Arch::LoongArch64 => write!(f, "loongarch64"),
         }
@@ -111,8 +117,8 @@ impl Arch {
             Arch::Powerpc | Arch::Powerpc64Le | Arch::Powerpc64 => "powerpc",
             Arch::X86 => "i386",
             Arch::X86_64 => "amd64",
-            Arch::Riscv64 => "riscv",
-            Arch::Mips64el | Arch::Mipsel => "mips",
+            Arch::Riscv32 | Arch::Riscv64 => "riscv",
+            Arch::Mips64el | Arch::Mips64 | Arch::Mipsel | Arch::Mips => "mips",
             // sparc64 is unsupported since FreeBSD 13.0
             Arch::Sparc64 => "sparc64",
             Arch::Wasm32 => "wasm32",
@@ -135,9 +141,12 @@ fn get_supported_architectures(os: &Os) -> Vec<Arch> {
             Arch::S390X,
             Arch::X86,
             Arch::X86_64,
+            Arch::Riscv32,
             Arch::Riscv64,
             Arch::Mips64el,
+            Arch::Mips64,
             Arch::Mipsel,
+            Arch::Mips,
             Arch::Sparc64,
             Arch::LoongArch64,
         ],
@@ -152,6 +161,7 @@ fn get_supported_architectures(os: &Os) -> Vec<Arch> {
             Arch::Powerpc64Le,
             Arch::X86,
             Arch::X86_64,
+            Arch::Riscv32,
             Arch::Riscv64,
             Arch::Mips64el,
             Arch::Mipsel,
@@ -165,6 +175,7 @@ fn get_supported_architectures(os: &Os) -> Vec<Arch> {
             Arch::Powerpc,
             Arch::Powerpc64,
             Arch::Powerpc64Le,
+            Arch::Riscv32,
             Arch::Riscv64,
             Arch::Sparc64,
         ],
@@ -190,6 +201,12 @@ pub struct Target {
     pub(crate) user_specified: bool,
 }
 
+impl fmt::Display for Target {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        write!(f, "{}", self.triple)
+    }
+}
+
 impl Target {
     /// Uses the given target triple or tries the guess the current target by using the one used
     /// for compilation
@@ -231,7 +248,7 @@ impl Target {
         };
 
         let arch = match platform.architecture {
-            Architecture::X86_64 => Arch::X86_64,
+            Architecture::X86_64 | Architecture::X86_64h => Arch::X86_64,
             Architecture::X86_32(_) => Arch::X86,
             Architecture::Arm(arm_arch) => match arm_arch {
                 ArmArchitecture::Arm | ArmArchitecture::Armv6 => Arch::Armv6L,
@@ -243,9 +260,18 @@ impl Target {
             Architecture::Powerpc64le => Arch::Powerpc64Le,
             Architecture::S390x => Arch::S390X,
             Architecture::Wasm32 => Arch::Wasm32,
+            Architecture::Riscv32(_) => Arch::Riscv32,
             Architecture::Riscv64(_) => Arch::Riscv64,
-            Architecture::Mips64(Mips64Architecture::Mips64el) => Arch::Mips64el,
-            Architecture::Mips32(Mips32Architecture::Mipsel) => Arch::Mipsel,
+            Architecture::Mips64(mips64_arch) => match mips64_arch {
+                Mips64Architecture::Mips64el => Arch::Mips64el,
+                Mips64Architecture::Mips64 => Arch::Mips64,
+                _ => bail!("The architecture {} is not supported", mips64_arch),
+            },
+            Architecture::Mips32(mips32_arch) => match mips32_arch {
+                Mips32Architecture::Mipsel => Arch::Mipsel,
+                Mips32Architecture::Mips => Arch::Mips,
+                _ => bail!("The architecture {} is not supported", mips32_arch),
+            },
             Architecture::Sparc64 => Arch::Sparc64,
             Architecture::LoongArch64 => Arch::LoongArch64,
             unsupported => bail!("The architecture {} is not supported", unsupported),
@@ -323,10 +349,11 @@ impl Target {
             Arch::X86_64 => "x86_64",
             Arch::S390X => "s390x",
             Arch::Wasm32 => "wasm32",
+            Arch::Riscv32 => "riscv32",
             Arch::Riscv64 => "riscv64",
             // It's kinda surprising that Python doesn't include the `el` suffix
-            Arch::Mips64el => "mips64",
-            Arch::Mipsel => "mips",
+            Arch::Mips64el | Arch::Mips64 => "mips64",
+            Arch::Mipsel | Arch::Mips => "mips",
             Arch::Sparc64 => "sparc64",
             Arch::LoongArch64 => "loongarch64",
         }
@@ -368,9 +395,12 @@ impl Target {
             }
             Arch::Armv6L
             | Arch::Wasm32
+            | Arch::Riscv32
             | Arch::Riscv64
             | Arch::Mips64el
+            | Arch::Mips64
             | Arch::Mipsel
+            | Arch::Mips
             | Arch::Powerpc
             | Arch::Sparc64
             | Arch::LoongArch64 => PlatformTag::Linux,
@@ -387,6 +417,7 @@ impl Target {
             | Arch::S390X
             | Arch::Riscv64
             | Arch::Mips64el
+            | Arch::Mips64
             | Arch::Sparc64
             | Arch::LoongArch64 => 64,
             Arch::Armv6L
@@ -394,6 +425,8 @@ impl Target {
             | Arch::X86
             | Arch::Wasm32
             | Arch::Mipsel
+            | Arch::Mips
+            | Arch::Riscv32
             | Arch::Powerpc => 32,
         }
     }
@@ -502,7 +535,7 @@ impl Target {
 
     /// Returns true if the current platform's target env is Musl
     #[inline]
-    pub fn is_musl_target(&self) -> bool {
+    pub fn is_musl_libc(&self) -> bool {
         matches!(
             self.env,
             Environment::Musl
